@@ -21,25 +21,25 @@
 #define GCONF_XML_CACHE_H
 
 #include <gconf/gconf.h>
-#include <gnome-xml/tree.h>
+#include <libxml/tree.h>
 #include "xml-dir.h"
 
 typedef struct _Cache Cache;
 
 Cache*   cache_new        (const gchar  *root_dir,
-                           guint dir_mode,
-                           guint file_mode);
+                           guint         dir_mode,
+                           guint         file_mode);
 void     cache_destroy    (Cache        *cache);
 gboolean cache_sync       (Cache        *cache,
-                           GError  **err);
+                           GError      **err);
 void     cache_clean      (Cache        *cache,
                            GTime         older_than);
-void     cache_delete_dir (Cache        *cache,
-                           const gchar  *key,
-                           GError  **err);
 Dir*     cache_lookup     (Cache        *cache,
                            const gchar  *key,
-                           gboolean create_if_missing,
-                           GError  **err); 
+                           gboolean      create_if_missing,
+                           GError      **err);
+
+void xml_test_cache (void);
 
 #endif
+
