@@ -51,6 +51,7 @@
 #include <ctype.h>
 #include <syslog.h>
 #include <time.h>
+#include <sys/wait.h>
 
 /* This makes hash table safer when debugging */
 #ifndef GCONF_ENABLE_DEBUG
@@ -409,6 +410,8 @@ signal_handler (int signo)
     break;
 
   case SIGUSR1:
+    --in_fatal;
+    
     /* it'd be nice to log a message here but it's not very safe, so */
     gconf_log_debug_messages = !gconf_log_debug_messages;
     break;
@@ -476,6 +479,10 @@ main(int argc, char** argv)
   char *gconfd_dir;
   int dev_null_fd;
   int write_byte_fd;
+
+  _gconf_init_i18n ();
+  setlocale (LC_ALL, "");
+  textdomain (GETTEXT_PACKAGE);
   
   /* Now this is an argument parser */
   if (argc > 1)
@@ -551,7 +558,8 @@ main(int argc, char** argv)
   sigaction (SIGHUP,  &act, 0);
   sigaction (SIGSEGV, &act, 0);
   sigaction (SIGABRT, &act, 0);
-
+  sigaction (SIGUSR1,  &act, 0);
+  
   act.sa_handler = SIG_IGN;
   sigaction (SIGINT, &act, 0);
 
@@ -724,15 +732,11 @@ gconf_main(void)
 {
   GMainLoop* loop;
 
-  loop = g_main_new(TRUE);
+  loop = g_main_loop_new (NULL, TRUE);
 
   if (main_loops == NULL)
     {
-#ifdef GCONF_ENABLE_DEBUG
-      gulong timeout_len = 1000*60*1; /* 1 sec * 60 s/min * 1 min */
-#else
-      gulong timeout_len = 1000*60*15; /* 1 sec * 60 s/min * 2 min */
-#endif
+      gulong timeout_len = 1000*60*2; /* 1 sec * 60 s/min * 2 min */
       
       g_assert(timeout_id == 0);
       timeout_id = g_timeout_add (timeout_len,
@@ -743,7 +747,7 @@ gconf_main(void)
   
   main_loops = g_slist_prepend(main_loops, loop);
 
-  g_main_run(loop);
+  g_main_loop_run (loop);
 
   main_loops = g_slist_remove(main_loops, loop);
 
@@ -754,7 +758,7 @@ gconf_main(void)
       timeout_id = 0;
     }
   
-  g_main_destroy(loop);
+  g_main_loop_unref (loop);
 }
 
 static void 
@@ -762,7 +766,7 @@ gconf_main_quit(void)
 {
   g_return_if_fail(main_loops != NULL);
 
-  g_main_quit(main_loops->data);
+  g_main_loop_quit (main_loops->data);
 }
 
 static gboolean
@@ -1060,7 +1064,7 @@ gconf_set_exception(GError** error,
     CORBA_exception_set(ev, CORBA_USER_EXCEPTION,
                         ex_ConfigException, ce);
 
-    gconf_log(GCL_ERR, _("Returning exception: %s"), (*error)->message);
+    gconf_log(GCL_DEBUG, _("Returning exception: %s"), (*error)->message);
       
     g_error_free(*error);
     *error = NULL;
@@ -1411,7 +1415,7 @@ parse_listener_entry (GHashTable *entries,
       return FALSE;
     }
   
-  while (*p && isspace (*p))
+  while (*p && g_ascii_isspace (*p))
     ++p;
 
   errno = 0;
@@ -1434,7 +1438,7 @@ parse_listener_entry (GHashTable *entries,
   
   p = end;
 
-  while (*p && isspace (*p))
+  while (*p && g_ascii_isspace (*p))
     ++p;
 
   err = NULL;
@@ -1454,7 +1458,7 @@ parse_listener_entry (GHashTable *entries,
   address = p;
   p = end;
 
-  while (*p && isspace (*p))
+  while (*p && g_ascii_isspace (*p))
     ++p;
   
   err = NULL;
@@ -1474,7 +1478,7 @@ parse_listener_entry (GHashTable *entries,
   location = p;
   p = end;
 
-  while (*p && isspace (*p))
+  while (*p && g_ascii_isspace (*p))
     ++p;
   
   err = NULL;
@@ -1578,7 +1582,7 @@ parse_client_entry (GHashTable *clients,
       return FALSE;
     }
   
-  while (*p && isspace (*p))
+  while (*p && g_ascii_isspace (*p))
     ++p;
   
   err = NULL;
@@ -2120,12 +2124,21 @@ add_client (const ConfigListener client)
     {
       CORBA_Environment ev;
       ConfigListener copy;
+      ORBitConnection *connection;
       
       CORBA_exception_init (&ev);
       copy = CORBA_Object_duplicate (client, &ev);
       g_hash_table_insert (client_table, copy, copy);
       CORBA_exception_free (&ev);
 
+      /* Set maximum buffer size, which makes the connection nonblocking
+       * if the kernel buffers are full and keeps gconfd from
+       * locking up. Set the max to a pretty high number to avoid
+       * dropping clients that are just stuck for a while.
+       */
+      connection = ORBit_small_get_connection (copy);
+      ORBit_connection_set_max_buffer (connection, 1024 * 128);
+      
       log_client_add (client);
 
       gconf_log (GCL_DEBUG, "Added a new client");
@@ -2289,7 +2302,9 @@ gconf_handle_segv (int signum)
 {
   static int in_segv = 0;
   pid_t pid;
-	
+
+  return;
+  
   in_segv++;
 
   if (in_segv > 2)
@@ -2310,7 +2325,9 @@ gconf_handle_segv (int signum)
     {
       /* Eeeek! Can't show dialog */
       fprintf (stderr, _("Segmentation fault!\n"
-                         "Cannot display crash dialog\n"));
+                         "Cannot display crash dialog: %s\n"),
+               strerror (errno));
+      fflush (stderr);
       
       /* Don't use app attributes here - a lot of things are probably hosed */
       if (g_getenv ("GNOME_DUMP_CORE"))
@@ -2341,7 +2358,7 @@ gconf_handle_segv (int signum)
       g_snprintf (buf, sizeof (buf), "%d", signum);
       
       /* Child process */
-      execl (GCONF_BINDIR "/gnome_segv2", GCONF_BINDIR "/gnome_segv",
+      execl (GCONF_BINDIR "/gnome_segv2", GCONF_BINDIR "/gnome_segv2",
              GCONFD, buf,
              VERSION, NULL);
       
@@ -2355,3 +2372,10 @@ gconf_handle_segv (int signum)
   in_segv--;
 }
 
+
+
+
+
+
+
+
